@@ -90,22 +90,26 @@ make_inits <- function(model, fct_args, priors, chains) {
 #' @param y A \code{\link[base]{numeric}} vector containing the y response.
 #' @param n_trials A \code{\link[base]{numeric}} vector indicating
 #' how many attempts the function should run before giving up.
+#' @param seed seed number for reproducible random number generation. Defaults
+#' to \code{NULL}.
 #' @param ... Additional arguments to \code{\link{make_inits}}.
 #'
 #' @seealso \code{\link{make_inits}}
 #' @return A \code{\link[base]{list}} containing the initialisation values.
 #'
 #' @noRd
-make_good_inits <- function(model, x, y, n_trials = 1e5, ...) {
+make_good_inits <- function(model, x, y, n_trials = 1e5, seed = NULL, ...) {
   limits <- range(y, na.rm = TRUE)
   pred_fct <- get(paste0("pred_", model))
   fct_args <- names(unlist(as.list(args(pred_fct))))
   fct_args <- setdiff(fct_args, "x")
+  set.seed(seed)
   inits <- make_inits(model, fct_args, ...)
   init_ranges <- lapply(inits, get_init_ranges, x, pred_fct, fct_args)
   are_good <- all(sapply(init_ranges, check_limits, limits))
   n_t <- 1
   while (!are_good && n_t <= n_trials) {
+    set.seed(seed + n_t)
     inits <- make_inits(model, fct_args, ...)
     init_ranges <- lapply(inits, get_init_ranges, x, pred_fct, fct_args)
     are_good <- all(sapply(init_ranges, check_limits, limits))
