@@ -22,9 +22,23 @@
 #' 0.975 (95 percent credible intervals).
 #'
 #' @details For \code{hormesis_def}, if "max", then NSEC values are calculated
-#' as a decline from the maximum estimates (i.e. the peak at nec);
+#' as a decline from the maximum estimates (i.e. the peak at NEC);
 #' if "control", then ECx values are calculated relative to the control, which
 #' is assumed to be the lowest observed concentration.
+#' 
+#' Calls to functions \code{\link{ecx}} and \code{\link{nsec}} and
+#' \code{\link{compare_fitted}} do not require the same level of flexibility
+#' in the context of allowing argument \code{newdata}
+#' (from a \code{\link[brms]{posterior_predict}} perspective) to
+#' be supplied manually, as this is and should be handled within the function
+#' itself. The argument \code{precision} controls how precisely the
+#' \code{\link{ecx}} or \code{\link{nsec}} value is estimated, with 
+#' argument \code{x_range} allowing estimation beyond the existing range of
+#' the observed data (otherwise the default range) which can be useful in a
+#' small number of cases. There is also no reasonable case where estimating
+#' these from the raw data would be of value, because both functions would
+#' simply return one of the treatment concentrations, making NOEC a better
+#' metric in that case.
 #'
 #' @seealso \code{\link{bnec}}
 #'
@@ -42,7 +56,7 @@
 #' @export
 nsec <- function(object, sig_val = 0.01, precision = 1000,
                  posterior = FALSE, x_range = NA, hormesis_def = "control",
-                 xform = NA, prob_vals = c(0.5, 0.025, 0.975)) {
+                 xform = identity, prob_vals = c(0.5, 0.025, 0.975)) {
   UseMethod("nsec")
 }
 
@@ -53,18 +67,31 @@ nsec <- function(object, sig_val = 0.01, precision = 1000,
 #'
 #' @inherit nsec details seealso return examples
 #' 
-#' @importFrom stats quantile predict
-#' @importFrom brms as_draws_df
-#'
+#' @importFrom stats quantile
+#' @importFrom brms as_draws_df posterior_epred
+#' @importFrom chk chk_logical chk_numeric
+#' 
 #' @noRd
 #'
 #' @export
-nsec.default <- function(object, sig_val = 0.01, precision = 1000,
-                         posterior = FALSE, x_range = NA,
-                         hormesis_def = "control", xform = NA,
-                         prob_vals = c(0.5, 0.025, 0.975)) {
-  if (length(prob_vals) < 3 | prob_vals[1] < prob_vals[1] |
-        prob_vals[1] > prob_vals[3] | prob_vals[2] > prob_vals[3]) {
+nsec.bayesnecfit <- function(object, sig_val = 0.01, precision = 1000,
+                             posterior = FALSE, x_range = NA,
+                             hormesis_def = "control", xform = identity,
+                             prob_vals = c(0.5, 0.025, 0.975)) {
+  chk_numeric(sig_val)
+  chk_numeric(precision)
+  chk_logical(posterior)
+  if (length(sig_val)>1) {
+    stop("You may only pass one sig_val")  
+  }
+  if ((hormesis_def %in% c("max", "control")) == FALSE) {
+    stop("type must be one of \"max\" or \"control\" (the default). ",
+         "Please see ?ecx for more details.")
+  }
+  if(!inherits(xform, "function")) { 
+    stop("xform must be a function.")}  
+  if (length(prob_vals) < 3 | prob_vals[1] < prob_vals[2] |
+      prob_vals[1] > prob_vals[3] | prob_vals[2] > prob_vals[3]) {
     stop("prob_vals must include central, lower and upper quantiles,",
          " in that order.")
   }
@@ -73,9 +100,12 @@ nsec.default <- function(object, sig_val = 0.01, precision = 1000,
   } else {
     mod_class <- "nec"
   }
-  pred_vals <- predict(object, precision = precision, x_range = x_range)
-  p_samples <- pred_vals$posterior
-  x_vec <- pred_vals$data$x
+  newdata_list <- newdata_eval(
+    object, precision = precision, x_range = x_range
+  )
+  p_samples <- posterior_epred(object, newdata = newdata_list$newdata,
+                               re_formula = NA)
+  x_vec <- newdata_list$x_vec
   reference <- quantile(p_samples[, 1], sig_val)
   if (grepl("horme", object$model)) {
     n <- seq_len(nrow(p_samples))
@@ -83,8 +113,7 @@ nsec.default <- function(object, sig_val = 0.01, precision = 1000,
                             p_samples, hormesis_def, fct = "rbind")
     nec_posterior <- as_draws_df(object$fit)[["b_nec_Intercept"]]
     if (hormesis_def == "max") {
-      reference <- quantile(apply(pred_vals$posterior, 2, max),
-                            probs = sig_val)
+      reference <- quantile(apply(p_samples, 2, max), probs = sig_val)
     }
   }
   nsec_out <- apply(p_samples, 1, nsec_fct, reference, x_vec)
@@ -98,13 +127,14 @@ nsec.default <- function(object, sig_val = 0.01, precision = 1000,
   if (inherits(xform, "function")) {
     nsec_out <- xform(nsec_out)
   }
-  label <- paste("ec", sig_val, sep = "_")
   nsec_estimate <- quantile(unlist(nsec_out), probs = prob_vals)
-  names(nsec_estimate) <- paste(label, clean_names(nsec_estimate), sep = "_")
+  names(nsec_estimate) <- clean_names(nsec_estimate)
   attr(nsec_estimate, "precision") <- precision
   attr(nsec_out, "precision") <- precision
   attr(nsec_estimate, "sig_val") <- sig_val
   attr(nsec_out, "sig_val") <- sig_val
+  attr(nsec_estimate, "toxicity_estimate") <- "nsec"
+  attr(nsec_out, "toxicity_estimate") <-  "nsec"
   if (!posterior) {
     nsec_estimate
   } else {
@@ -112,26 +142,6 @@ nsec.default <- function(object, sig_val = 0.01, precision = 1000,
   }
 }
 
-#' @inheritParams nsec
-#'
-#' @param object An object of class \code{\link{bayesnecfit}} returned by
-#' \code{\link{bnec}}.
-#'
-#' @inherit nsec details seealso return examples
-#' 
-#' @noRd
-#'
-#' @export
-nsec.bayesnecfit <- function(object, sig_val = 0.01, precision = 1000,
-                             posterior = FALSE, x_range = NA,
-                             hormesis_def = "control", xform = NA,
-                             prob_vals = c(0.5, 0.025, 0.975)) {
-  nsec.default(object, sig_val = sig_val, precision = precision,
-               posterior = posterior, x_range = x_range,
-               hormesis_def = hormesis_def, xform = xform, 
-               prob_vals = prob_vals)
-}
-
 #' @inheritParams nsec
 #'
 #' @param object An object of class \code{\link{bayesmanecfit}} returned by
@@ -146,8 +156,11 @@ nsec.bayesnecfit <- function(object, sig_val = 0.01, precision = 1000,
 #' @export
 nsec.bayesmanecfit <- function(object, sig_val = 0.01, precision = 1000,
                                posterior = FALSE, x_range = NA,
-                               hormesis_def = "control", xform = NA,
+                               hormesis_def = "control", xform = identity,
                                prob_vals = c(0.5, 0.025, 0.975)) {
+  if (length(sig_val)>1) {
+    stop("You may only pass one sig_val")  
+  }
   sample_nsec <- function(x, object, sig_val, precision,
                           posterior, hormesis_def,
                           x_range, xform, prob_vals, sample_size) {
@@ -165,14 +178,14 @@ nsec.bayesmanecfit <- function(object, sig_val = 0.01, precision = 1000,
                      posterior = TRUE, hormesis_def, x_range,
                      xform, prob_vals, sample_size)
   nsec_out <- unlist(nsec_out)
-  label <- paste("ec", sig_val, sep = "_")
   nsec_estimate <- quantile(nsec_out, probs = prob_vals)
-  names(nsec_estimate) <- c(label, paste(label, "lw", sep = "_"),
-                            paste(label, "up", sep = "_"))
+  names(nsec_estimate) <- clean_names(nsec_estimate)
   attr(nsec_estimate, "precision") <- precision
   attr(nsec_out, "precision") <- precision
   attr(nsec_estimate, "sig_val") <- sig_val
   attr(nsec_out, "sig_val") <- sig_val
+  attr(nsec_estimate, "toxicity_estimate") <- "nsec"
+  attr(nsec_out, "toxicity_estimate") <-  "nsec"
   if (!posterior) {
     nsec_estimate
   } else {
