@@ -80,12 +80,12 @@ test_that("check proper output structure", {
   expect_true(grepl("normal", p_a$prior[p_a$nlpar == "beta"]))
   expect_true(grepl("normal", p_a$prior[p_a$nlpar == "nec"]))
   expect_true(grepl("normal", p_a$prior[p_a$nlpar == "top"]))
-  expect_true(p_b$bound[p_b$nlpar == "top"] == "")
-  expect_true(p_b$bound[p_b$nlpar == "bot"] == "")
+  expect_true(all(is.na(p_b[p_b$nlpar == "top", c("lb", "ub")])))
+  expect_true(all(is.na(p_b[p_b$nlpar == "bot", c("lb", "ub")])))
   expect_true(grepl("normal", p_b$prior[p_b$nlpar == "top"]))
   expect_true(grepl("normal", p_b$prior[p_b$nlpar == "bot"]))
-  expect_false(p_c$bound[p_c$nlpar == "top"] == "")
-  expect_false(p_c$bound[p_c$nlpar == "bot"] == "")
+  expect_false(all(is.na(p_c[p_c$nlpar == "top", c("lb", "ub")])))
+  expect_false(all(is.na(p_c[p_c$nlpar == "bot", c("lb", "ub")])))
   expect_true(grepl("beta", p_c$prior[p_c$nlpar == "top"]))
   expect_true(grepl("beta", p_c$prior[p_c$nlpar == "bot"]))
 })
